##
##  corvus.spec -- OpenPKG RPM Package Specification
##  Copyright (c) 2000-2023 OpenPKG Project <http://openpkg.org/>
##
##  Permission to use, copy, modify, and distribute this software for
##  any purpose with or without fee is hereby granted, provided that
##  the above copyright notice and this permission notice appear in all
##  copies.
##
##  THIS SOFTWARE IS PROVIDED ``AS IS'' AND ANY EXPRESSED OR IMPLIED
##  WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
##  MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
##  IN NO EVENT SHALL THE AUTHORS AND COPYRIGHT HOLDERS AND THEIR
##  CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
##  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
##  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF
##  USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
##  ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
##  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT
##  OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
##  SUCH DAMAGE.
##

#   package information
Name:         corvus
Summary:      Redis Cluster Proxy
URL:          https://github.com/eleme/corvus
Vendor:       Eleme Inc.
Packager:     OpenPKG Project
Distribution: OpenPKG Community
Class:        EVAL
Group:        Database
License:      MIT
Version:      0.2.7
Release:      20230624

#   list of sources
Source0:      https://github.com/eleme/corvus/releases/download/v%{version}/corvus-%{version}.tar.bz2
Source1:      corvus.conf
Source2:      rc.corvus
Patch0:       corvus.patch

#   build information
BuildPreReq:  OpenPKG, openpkg >= 20160101
PreReq:       OpenPKG, openpkg >= 20160101

%description
    Corvus is a fast and lightweight Redis cluster proxy for Redis 3/4
    with cluster mode enabled.

%track
    prog corvus = {
        version   = %{version}
        url       = https://github.com/eleme/corvus/releases
        regex     = tree/v(__VER__)
    }

%prep
    %setup -q
    %patch -p0

%build
    #   build program
    %{l_make} %{l_mflags} \
        CC="%{l_cc} %{l_cflags -O} %{l_cppflags} %{l_ldflags}"

%install
    #   create installation hierarchy
    %{l_shtool} mkdir -f -p -m 755 \
        $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d \
        $RPM_BUILD_ROOT%{l_prefix}/etc/corvus \
        $RPM_BUILD_ROOT%{l_prefix}/sbin \
        $RPM_BUILD_ROOT%{l_prefix}/var/corvus/log \
        $RPM_BUILD_ROOT%{l_prefix}/var/corvus/run

    #   install program
    %{l_shtool} install -c -s -m 755 \
        src/corvus $RPM_BUILD_ROOT%{l_prefix}/sbin/

    #   install default configuration
    %{l_shtool} install -c -m 644 %{l_value -s -a} \
        %{SOURCE corvus.conf} $RPM_BUILD_ROOT%{l_prefix}/etc/corvus/

    #   install run-command script
    %{l_shtool} install -c -m 755 %{l_value -s -a} \
        %{SOURCE rc.corvus} $RPM_BUILD_ROOT%{l_prefix}/etc/rc.d/

    #   determine installation files
    %{l_rpmtool} files -v -ofiles -r$RPM_BUILD_ROOT \
        %{l_files_std} \
        '%config %{l_prefix}/etc/corvus/*' \
        '%attr(-,%{l_rusr},%{l_rgrp}) %{l_prefix}/var/corvus/*'

%files -f files

%clean

%post
    if [ $1 -eq 2 ]; then
        #   after upgrade, restart service
        eval `%{l_rc} corvus status 2>/dev/null`
        [ ".$corvus_active" = .yes ] && %{l_rc} corvus restart
    fi
    exit 0

%preun
    if [ $1 -eq 0 ]; then
        #   before erase, stop service and remove log files
        %{l_rc} corvus stop 2>/dev/null
        rm -f $RPM_INSTALL_PREFIX/var/corvus/run/* >/dev/null 2>&1 || true
        rm -f $RPM_INSTALL_PREFIX/var/corvus/log/* >/dev/null 2>&1 || true
    fi
    exit 0

